Enum rkyv::option::ArchivedOption [−][src]
#[repr(u8)]
pub enum ArchivedOption<T> {
None,
Some(T),
}Expand description
Variants
None
No value
Some(T)
Some value T
Implementations
Converts from Pin<&ArchivedOption<T>> to Option<Pin<&T>>.
Converts from Pin<&mut ArchivedOption<T>> to Option<Pin<&mut T>>.
Returns an iterator over the possibly contained value.
Returns a mutable iterator over the possibly contained value.
Inserts v into the option if it is None, then returns a mutable
reference to the contained value.
Inserts a value computed from f into the option if it is None, then
returns a mutable reference to the contained value.
Converts from &mut ArchivedOption<T> to Option<&mut T::Target>.
Leaves the original ArchivedOption in-place, creating a new Option with a mutable
reference to the inner type’s Deref::Target type.